@@ -15,3 +15,7 @@ with version_path.open(encoding = "utf-8") as version_file:
 
 def setup(app):
     app.add_html_theme('nextstrain-sphinx-theme', str(package_dir))
+    app.setup_extension('sphinx_copybutton')
+    # customize sphinx_copybutton https://sphinx-copybutton.readthedocs.io/en/latest/use.html
+    app.config['copybutton_prompt_text'] = '$ '
+    app.config['copybutton_line_continuation_character'] = '\\'
